*******
How Tos
*******

.. contents:: Contents
   :depth: 4
   :local:

.. include:: developer_information/how_tos/adding_plugins.rst

.. include:: developer_information/how_tos/processing_output.rst
